@@ -58,6 +58,11 @@ void	config(int argc, char **argv)
                         {
                                 dbOutPort = htons(atoi(pnt));
                         }
+                        else if (!memcmp (buff, "TRUST_DB_DOMAIN_NAME", 20))
+                        {
+                                memset (TrustDbDomainName, 0x00, 128);
+                                memcpy (TrustDbDomainName, pnt, strlen(pnt));
+                        }
 		}
 	}
 	fclose (config_file);
